#!/bin/dash

set -e

# ---------------------------------------------------------------------- #
# Show a 0..100% progress notification using a synchronous hint

summary=" progress"
colors="-h string:bgcolor:#000000 -h string:fgcolor:#ffffff"
for p in `seq 0 100`; do
	dunstify "$summary" $colors \
		-h string:synchronous:my_progress -h int:value:$p -h string:x-canonical-private-synchronous:script
done

# ---------------------------------------------------------------------- #
# Show a 0..100% progress notification using an id instead of a synchronous hint

id=$(dunstify " " -t 1 -p) # get an id
summary=" progress"
colors="-h string:bgcolor:#009944 -h string:fgcolor:#ffffff"
for p in `seq 0 100`; do
	dunstify "$summary" $colors \
		-r $id -h int:value:$p
done

# ---------------------------------------------------------------------- #
# Same with a progress bar

# This progress bar would replace the one above if we didn't get a new id.
id=$(dunstify " " -t 1 -p) # get a new id
summary=" progress bar"
colors="-h string:bgcolor:#ffffff -h string:fgcolor:#000000"
_bar_max=100 _bar_step=10 _bar_char=" █" # $' \u2588'
_bar_bar= # is the whole bar
for p in `seq 0 $_bar_step $_bar_max`; do
	_bar_bar="$_bar_bar$_bar_char"
done
set_BAR() { # $1-progress-value
	local i=$(( ${1:-0} * 100 / $_bar_max / $_bar_step)) max=$(( $_bar_max / $_bar_step ))
	BAR=$_bar_bar
	while [ $i -lt $max ]; do
		case $_bar_char in
			? ) BAR=${BAR%?} ;;
			?? ) BAR=${BAR%??} ;;
			??? ) BAR=${BAR%???} ;;
			???? ) BAR=${BAR%????} ;;
			# and so on according to _bar_char length
		esac
		i=$(($i + 1))
	done
}
for p in `seq 0 $_bar_max`; do
	set_BAR $p
	dunstify "$summary" "$BAR" $colors \
		-r $id -h int:value:$p
done

# ---------------------------------------------------------------------- #
# The grand finale from our mascotte!

fatdog_icon=/usr/share/lxqt/themes/ambiance/mainmenu.svg
sleep 3
dunstify "$summary" "<big>woof! woof!</big>\n" $colors \
	-r $id -h int:value:$p -i "$fatdog_icon"

